<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Hait
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function hait_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class space-disabled if Disable space meta value is true
	$disable_space = get_post_meta( absint( get_the_ID() ), 'disable_space', true );

	if ( ( 'checked' === $disable_space ) && is_singular() ) {
		$classes[] = 'space-disabled';
	}

	// Adds a class list or grid for blog layout
	$global_layout = hait_get_option( 'global_layout' );
	$classes[] = 'global-layout-' . esc_attr( $global_layout );

	// Adds a class list or grid for blog layout
	$enable_banner = hait_get_option( 'enable_banner' );
	if ( ( true === $enable_banner ) ) {
		$classes[] = 'banner-enabled';
	}

	// Adds a class grid-column for blog layout
	$grid_number = hait_get_option( 'grid_number' );
	$classes[] = 'grid-column-' . esc_attr( $grid_number );

	return $classes;
}
add_filter( 'body_class', 'hait_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function hait_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'hait_pingback_header' );

/**
 * Add a dropdown icon to header menu.
 */
add_filter( 'nav_menu_item_title', 'hait_add_dropdown_icons', 10, 4 );

if ( ! function_exists( 'hait_add_dropdown_icons' ) ) {

	function hait_add_dropdown_icons( $title, $item, $args, $depth ) {

		$icon = '<svg role="img" viewBox="0 0 10 6" xmlns="http://www.w3.org/2000/svg"><path d="M1 1l4 4 4-4" stroke="currentColor" stroke-width="1.5" fill="none" fill-rule="evenodd" stroke-linecap="square"/></svg>';

		if ( 'menu-1' === $args->theme_location && (0 === $depth || 1 === $depth) ) {
			foreach ( $item->classes as $value ) {
				if ( 'menu-item-has-children' === $value || 'page_item_has_children' === $value ) {
					$title = $title . '<span role="presentation" class="dropdown-menu-toggle">' . $icon . '</span>';
				}
			}
		}

		return $title;

	}

}

//=============================================================
// Function to change default excerpt
//=============================================================
if ( ! function_exists( 'hait_implement_excerpt_length' ) ) :

	/**
	 * Implement excerpt length.
	 *
	 * @since 1.0.0
	 *
	 * @param int $length The number of words.
	 * @return int Excerpt length.
	 */
	function hait_implement_excerpt_length( $length ) {

		$excerpt_length = hait_get_option( 'excerpt_length' );

		if ( absint( $excerpt_length ) > 0 ) {
			$length = absint( $excerpt_length );
		}
		return $length;

	}
endif;

if ( ! function_exists( 'hait_content_more_link' ) ) :

	/**
	 * Implement read more in content.
	 *
	 * @since 1.0.0
	 *
	 * @param string $more_link Read More link element.
	 * @param string $more_link_text Read More text.
	 * @return string Link.
	 */
	function hait_content_more_link( $more_link, $more_link_text ) {

		$read_more_text = hait_get_option( 'readmore_text' );

		if ( ! empty( $read_more_text ) ) {

			$more_link = str_replace( $more_link_text, esc_html( $read_more_text ), $more_link );

		}

		return $more_link;

	}

endif;

if ( ! function_exists( 'hait_implement_read_more' ) ) :

	/**
	 * Implement read more in excerpt.
	 *
	 * @since 1.0.0
	 *
	 * @param string $more The string shown within the more link.
	 * @return string The excerpt.
	 */
	function hait_implement_read_more( $more ) {

		$output = $more;

		$read_more_text = hait_get_option( 'readmore_text' );

		if ( ! empty( $read_more_text ) ) {

			$output = '&hellip;<p><a href="' . esc_url( get_permalink() ) . '" class="btn-more">' . esc_html( $read_more_text ) . '<span class="arrow-more">&rarr;</span></a></p>';

		}

		return $output;

	}
endif;

if ( ! function_exists( 'hait_hook_read_more_filters' ) ) :

	/**
	 * Hook read more and excerpt length filters.
	 *
	 * @since 1.0.0
	 */
	function hait_hook_read_more_filters() {

		add_filter( 'excerpt_length', 'hait_implement_excerpt_length', 999 );
		add_filter( 'the_content_more_link', 'hait_content_more_link', 10, 2 );
		add_filter( 'excerpt_more', 'hait_implement_read_more' );

	}
endif;
add_action( 'wp', 'hait_hook_read_more_filters' );

//=============================================================
// Menu Fallback function
//=============================================================

if ( ! function_exists( 'hait_menu_fallback' ) ) :

function hait_menu_fallback() {

	echo '<ul id="menu-main-menu" class="menu">';
		echo '<li class="menu-item"><a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html__( 'Home', 'hait' ). '</a></li>';
		wp_list_pages( array(
			'title_li' => '',
			'depth'    => 1,
			'number'   => 4,
		) );
	echo '</ul>';

}

endif;

//=============================================================
// Admin Notice function
//=============================================================

if ( !function_exists('hait_add_admin_notice') ) :

	function hait_add_admin_notice() {
		\Nilambar\AdminNotice\Notice::init(
			array(
				'slug' => 'hait',
				'type' => 'theme',
				'name' => esc_html__( 'Hait', 'hait' ),
			)
		);
	}

endif;

add_action( 'admin_init', 'hait_add_admin_notice' );
